-- Query generated by:
-- templates/clients_daily_scalar_aggregates.sql.py --agg-type scalars
WITH valid_build_ids AS (
  SELECT DISTINCT
    (build.build.id) AS build_id
  FROM
    `moz-fx-data-shared-prod.telemetry.buildhub2`
),
filtered AS (
  SELECT
    *,
    SPLIT(application.version, '.')[OFFSET(0)] AS app_version,
    DATE(submission_timestamp) AS submission_date,
    normalized_os AS os,
    application.build_id AS app_build_id,
    normalized_channel AS channel
  FROM
    `moz-fx-data-shared-prod.telemetry_stable.main_v5`
  INNER JOIN
    valid_build_ids
    ON (application.build_id = build_id)
  WHERE
    DATE(submission_timestamp) = @submission_date
    AND normalized_channel IN ("release", "beta", "nightly")
    AND client_id IS NOT NULL
),
sampled_data AS (
  SELECT
    *
  FROM
    filtered
  WHERE
    channel IN ("nightly", "beta")
    OR (channel = "release" AND os != "Windows")
    OR (channel = "release" AND os = "Windows" AND MOD(sample_id, @sample_size) = 0)
),
-- Using `min` for when `agg_type` is `count` returns null when all rows are null
aggregated AS (
  SELECT
    submission_date,
    sample_id,
    client_id,
    os,
    app_version,
    app_build_id,
    channel,
    ARRAY<
      STRUCT<
        metric STRING,
        metric_type STRING,
        key STRING,
        process STRING,
        agg_type STRING,
        value FLOAT64
      >
    >[
      (
        'a11y_backplate',
        'boolean',
        '',
        'parent',
        'false',
        SUM(CASE WHEN payload.processes.parent.scalars.a11y_backplate = FALSE THEN 1 ELSE 0 END)
      ),
      (
        'a11y_backplate',
        'boolean',
        '',
        'parent',
        'true',
        SUM(CASE WHEN payload.processes.parent.scalars.a11y_backplate = TRUE THEN 1 ELSE 0 END)
      ),
      (
        'a11y_indicator_acted_on',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.a11y_indicator_acted_on = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'a11y_indicator_acted_on',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.a11y_indicator_acted_on = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'a11y_sitezoom',
        'boolean',
        '',
        'parent',
        'false',
        SUM(CASE WHEN payload.processes.parent.scalars.a11y_sitezoom = FALSE THEN 1 ELSE 0 END)
      ),
      (
        'a11y_sitezoom',
        'boolean',
        '',
        'parent',
        'true',
        SUM(CASE WHEN payload.processes.parent.scalars.a11y_sitezoom = TRUE THEN 1 ELSE 0 END)
      ),
      (
        'browser_engagement_active_ticks',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_engagement_active_ticks AS INT64))
      ),
      (
        'browser_engagement_active_ticks',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_active_ticks) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_active_ticks',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_engagement_active_ticks AS INT64))
      ),
      (
        'browser_engagement_active_ticks',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_engagement_active_ticks AS INT64))
      ),
      (
        'browser_engagement_active_ticks',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_engagement_active_ticks AS INT64))
      ),
      (
        'browser_engagement_max_concurrent_tab_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_pinned_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_pinned_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_pinned_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_pinned_count
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_pinned_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_pinned_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_pinned_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_pinned_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_tab_pinned_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_tab_pinned_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_window_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_window_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_window_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_window_count
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_max_concurrent_window_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_window_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_window_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_window_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_max_concurrent_window_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.browser_engagement_max_concurrent_window_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_restored_pinned_tabs_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.browser_engagement_restored_pinned_tabs_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_restored_pinned_tabs_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.browser_engagement_restored_pinned_tabs_count
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_restored_pinned_tabs_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.browser_engagement_restored_pinned_tabs_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_restored_pinned_tabs_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.browser_engagement_restored_pinned_tabs_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_restored_pinned_tabs_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.browser_engagement_restored_pinned_tabs_count AS INT64
          )
        )
      ),
      (
        'browser_engagement_tab_open_event_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_engagement_tab_open_event_count AS INT64))
      ),
      (
        'browser_engagement_tab_open_event_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_tab_open_event_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_tab_open_event_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_engagement_tab_open_event_count AS INT64))
      ),
      (
        'browser_engagement_tab_open_event_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_engagement_tab_open_event_count AS INT64))
      ),
      (
        'browser_engagement_tab_open_event_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_engagement_tab_open_event_count AS INT64))
      ),
      (
        'browser_engagement_tab_pinned_event_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.browser_engagement_tab_pinned_event_count AS INT64)
        )
      ),
      (
        'browser_engagement_tab_pinned_event_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_tab_pinned_event_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_tab_pinned_event_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.browser_engagement_tab_pinned_event_count AS INT64)
        )
      ),
      (
        'browser_engagement_tab_pinned_event_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.browser_engagement_tab_pinned_event_count AS INT64)
        )
      ),
      (
        'browser_engagement_tab_pinned_event_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.browser_engagement_tab_pinned_event_count AS INT64)
        )
      ),
      (
        'browser_engagement_total_uri_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_engagement_total_uri_count AS INT64))
      ),
      (
        'browser_engagement_total_uri_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_total_uri_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_total_uri_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_engagement_total_uri_count AS INT64))
      ),
      (
        'browser_engagement_total_uri_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_engagement_total_uri_count AS INT64))
      ),
      (
        'browser_engagement_total_uri_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_engagement_total_uri_count AS INT64))
      ),
      (
        'browser_engagement_unfiltered_uri_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_engagement_unfiltered_uri_count AS INT64))
      ),
      (
        'browser_engagement_unfiltered_uri_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_unfiltered_uri_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_unfiltered_uri_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_engagement_unfiltered_uri_count AS INT64))
      ),
      (
        'browser_engagement_unfiltered_uri_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_engagement_unfiltered_uri_count AS INT64))
      ),
      (
        'browser_engagement_unfiltered_uri_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_engagement_unfiltered_uri_count AS INT64))
      ),
      (
        'browser_engagement_unique_domains_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_engagement_unique_domains_count AS INT64))
      ),
      (
        'browser_engagement_unique_domains_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_unique_domains_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_unique_domains_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_engagement_unique_domains_count AS INT64))
      ),
      (
        'browser_engagement_unique_domains_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_engagement_unique_domains_count AS INT64))
      ),
      (
        'browser_engagement_unique_domains_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_engagement_unique_domains_count AS INT64))
      ),
      (
        'browser_engagement_window_open_event_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.browser_engagement_window_open_event_count AS INT64)
        )
      ),
      (
        'browser_engagement_window_open_event_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_engagement_window_open_event_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_engagement_window_open_event_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.browser_engagement_window_open_event_count AS INT64)
        )
      ),
      (
        'browser_engagement_window_open_event_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.browser_engagement_window_open_event_count AS INT64)
        )
      ),
      (
        'browser_engagement_window_open_event_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.browser_engagement_window_open_event_count AS INT64)
        )
      ),
      (
        'browser_errors_collected_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_errors_collected_count AS INT64))
      ),
      (
        'browser_errors_collected_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_errors_collected_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_errors_collected_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_errors_collected_count AS INT64))
      ),
      (
        'browser_errors_collected_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_errors_collected_count AS INT64))
      ),
      (
        'browser_errors_collected_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_errors_collected_count AS INT64))
      ),
      (
        'browser_errors_collected_with_stack_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.browser_errors_collected_with_stack_count AS INT64)
        )
      ),
      (
        'browser_errors_collected_with_stack_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_errors_collected_with_stack_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_errors_collected_with_stack_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.browser_errors_collected_with_stack_count AS INT64)
        )
      ),
      (
        'browser_errors_collected_with_stack_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.browser_errors_collected_with_stack_count AS INT64)
        )
      ),
      (
        'browser_errors_collected_with_stack_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.browser_errors_collected_with_stack_count AS INT64)
        )
      ),
      (
        'browser_errors_reported_failure_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_errors_reported_failure_count AS INT64))
      ),
      (
        'browser_errors_reported_failure_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_errors_reported_failure_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_errors_reported_failure_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_errors_reported_failure_count AS INT64))
      ),
      (
        'browser_errors_reported_failure_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_errors_reported_failure_count AS INT64))
      ),
      (
        'browser_errors_reported_failure_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_errors_reported_failure_count AS INT64))
      ),
      (
        'browser_errors_reported_success_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_errors_reported_success_count AS INT64))
      ),
      (
        'browser_errors_reported_success_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_errors_reported_success_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_errors_reported_success_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_errors_reported_success_count AS INT64))
      ),
      (
        'browser_errors_reported_success_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_errors_reported_success_count AS INT64))
      ),
      (
        'browser_errors_reported_success_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_errors_reported_success_count AS INT64))
      ),
      (
        'browser_feeds_feed_subscribed',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_feeds_feed_subscribed AS INT64))
      ),
      (
        'browser_feeds_feed_subscribed',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_feeds_feed_subscribed) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_feeds_feed_subscribed',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_feeds_feed_subscribed AS INT64))
      ),
      (
        'browser_feeds_feed_subscribed',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_feeds_feed_subscribed AS INT64))
      ),
      (
        'browser_feeds_feed_subscribed',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_feeds_feed_subscribed AS INT64))
      ),
      (
        'browser_feeds_livebookmark_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_count AS INT64))
      ),
      (
        'browser_feeds_livebookmark_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_feeds_livebookmark_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_feeds_livebookmark_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_count AS INT64))
      ),
      (
        'browser_feeds_livebookmark_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_count AS INT64))
      ),
      (
        'browser_feeds_livebookmark_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_count AS INT64))
      ),
      (
        'browser_feeds_livebookmark_item_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_item_opened AS INT64))
      ),
      (
        'browser_feeds_livebookmark_item_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_feeds_livebookmark_item_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_feeds_livebookmark_item_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_item_opened AS INT64))
      ),
      (
        'browser_feeds_livebookmark_item_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_item_opened AS INT64))
      ),
      (
        'browser_feeds_livebookmark_item_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_item_opened AS INT64))
      ),
      (
        'browser_feeds_livebookmark_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_opened AS INT64))
      ),
      (
        'browser_feeds_livebookmark_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_feeds_livebookmark_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_feeds_livebookmark_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_opened AS INT64))
      ),
      (
        'browser_feeds_livebookmark_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_opened AS INT64))
      ),
      (
        'browser_feeds_livebookmark_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_feeds_livebookmark_opened AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.browser_feeds_preview_loaded) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_feeds_preview_loaded) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_feeds_preview_loaded',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_feeds_preview_loaded AS INT64))
      ),
      (
        'browser_searchinit_engines_cache_corrupted',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_searchinit_engines_cache_corrupted = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_searchinit_engines_cache_corrupted',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_searchinit_engines_cache_corrupted = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_session_restore_browser_startup_page',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_startup_page AS INT64
          )
        )
      ),
      (
        'browser_session_restore_browser_startup_page',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.browser_session_restore_browser_startup_page
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_session_restore_browser_startup_page',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_startup_page AS INT64
          )
        )
      ),
      (
        'browser_session_restore_browser_startup_page',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_startup_page AS INT64
          )
        )
      ),
      (
        'browser_session_restore_browser_startup_page',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_startup_page AS INT64
          )
        )
      ),
      (
        'browser_session_restore_browser_tabs_restorebutton',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_tabs_restorebutton AS INT64
          )
        )
      ),
      (
        'browser_session_restore_browser_tabs_restorebutton',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.browser_session_restore_browser_tabs_restorebutton
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_session_restore_browser_tabs_restorebutton',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_tabs_restorebutton AS INT64
          )
        )
      ),
      (
        'browser_session_restore_browser_tabs_restorebutton',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_tabs_restorebutton AS INT64
          )
        )
      ),
      (
        'browser_session_restore_browser_tabs_restorebutton',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_browser_tabs_restorebutton AS INT64
          )
        )
      ),
      (
        'browser_session_restore_number_of_tabs',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_tabs AS INT64))
      ),
      (
        'browser_session_restore_number_of_tabs',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_session_restore_number_of_tabs) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_session_restore_number_of_tabs',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_tabs AS INT64))
      ),
      (
        'browser_session_restore_number_of_tabs',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_tabs AS INT64))
      ),
      (
        'browser_session_restore_number_of_tabs',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_tabs AS INT64))
      ),
      (
        'browser_session_restore_number_of_win',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_win AS INT64))
      ),
      (
        'browser_session_restore_number_of_win',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_session_restore_number_of_win) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_session_restore_number_of_win',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_win AS INT64))
      ),
      (
        'browser_session_restore_number_of_win',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_win AS INT64))
      ),
      (
        'browser_session_restore_number_of_win',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_session_restore_number_of_win AS INT64))
      ),
      (
        'browser_session_restore_tabbar_restore_available',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_session_restore_tabbar_restore_available = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_session_restore_tabbar_restore_available',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_session_restore_tabbar_restore_available = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_session_restore_tabbar_restore_clicked',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_session_restore_tabbar_restore_clicked = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_session_restore_tabbar_restore_clicked',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_session_restore_tabbar_restore_clicked = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_session_restore_worker_restart_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_worker_restart_count AS INT64
          )
        )
      ),
      (
        'browser_session_restore_worker_restart_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.browser_session_restore_worker_restart_count
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_session_restore_worker_restart_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_worker_restart_count AS INT64
          )
        )
      ),
      (
        'browser_session_restore_worker_restart_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_worker_restart_count AS INT64
          )
        )
      ),
      (
        'browser_session_restore_worker_restart_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.browser_session_restore_worker_restart_count AS INT64
          )
        )
      ),
      (
        'browser_startup_action',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_startup_action AS INT64))
      ),
      (
        'browser_startup_action',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.browser_startup_action) IS NULL, NULL, COUNT(*))
      ),
      (
        'browser_startup_action',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_startup_action AS INT64))
      ),
      (
        'browser_startup_action',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_startup_action AS INT64))
      ),
      (
        'browser_startup_action',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_startup_action AS INT64))
      ),
      (
        'browser_startup_average_time',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_startup_average_time AS INT64))
      ),
      (
        'browser_startup_average_time',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_startup_average_time) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_startup_average_time',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_startup_average_time AS INT64))
      ),
      (
        'browser_startup_average_time',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_startup_average_time AS INT64))
      ),
      (
        'browser_startup_average_time',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_startup_average_time AS INT64))
      ),
      (
        'browser_startup_recorded_time',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_startup_recorded_time AS INT64))
      ),
      (
        'browser_startup_recorded_time',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_startup_recorded_time) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_startup_recorded_time',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_startup_recorded_time AS INT64))
      ),
      (
        'browser_startup_recorded_time',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_startup_recorded_time AS INT64))
      ),
      (
        'browser_startup_recorded_time',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_startup_recorded_time AS INT64))
      ),
      (
        'browser_startup_slow_startup_notification_disabled',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_startup_slow_startup_notification_disabled = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_startup_slow_startup_notification_disabled',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_startup_slow_startup_notification_disabled = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_startup_slow_startup_notified',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_startup_slow_startup_notified = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_startup_slow_startup_notified',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_startup_slow_startup_notified = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_startup_too_new_for_notification',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_startup_too_new_for_notification = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_startup_too_new_for_notification',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.browser_startup_too_new_for_notification = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'browser_timings_last_shutdown',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_timings_last_shutdown AS INT64))
      ),
      (
        'browser_timings_last_shutdown',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_timings_last_shutdown) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_timings_last_shutdown',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_timings_last_shutdown AS INT64))
      ),
      (
        'browser_timings_last_shutdown',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_timings_last_shutdown AS INT64))
      ),
      (
        'browser_timings_last_shutdown',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_timings_last_shutdown AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.browser_usage_graphite) IS NULL, NULL, COUNT(*))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'gpu',
        'avg',
        AVG(CAST(payload.processes.gpu.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'gpu',
        'count',
        IF(MIN(payload.processes.gpu.scalars.browser_usage_graphite) IS NULL, NULL, COUNT(*))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'gpu',
        'max',
        MAX(CAST(payload.processes.gpu.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'gpu',
        'min',
        MIN(CAST(payload.processes.gpu.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'gpu',
        'sum',
        SUM(CAST(payload.processes.gpu.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.browser_usage_graphite) IS NULL, NULL, COUNT(*))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_graphite',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_usage_graphite AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.browser_usage_plugin_instantiated) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.browser_usage_plugin_instantiated) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'browser_usage_plugin_instantiated',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.browser_usage_plugin_instantiated AS INT64))
      ),
      (
        'contentblocking_category',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.contentblocking_category AS INT64))
      ),
      (
        'contentblocking_category',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.contentblocking_category) IS NULL, NULL, COUNT(*))
      ),
      (
        'contentblocking_category',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.contentblocking_category AS INT64))
      ),
      (
        'contentblocking_category',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.contentblocking_category AS INT64))
      ),
      (
        'contentblocking_category',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.contentblocking_category AS INT64))
      ),
      (
        'contentblocking_cryptomining_blocking_enabled',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_cryptomining_blocking_enabled = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_cryptomining_blocking_enabled',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_cryptomining_blocking_enabled = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_enabled',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_enabled = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_enabled',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_enabled = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_exceptions',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.contentblocking_exceptions AS INT64))
      ),
      (
        'contentblocking_exceptions',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.contentblocking_exceptions) IS NULL, NULL, COUNT(*))
      ),
      (
        'contentblocking_exceptions',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.contentblocking_exceptions AS INT64))
      ),
      (
        'contentblocking_exceptions',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.contentblocking_exceptions AS INT64))
      ),
      (
        'contentblocking_exceptions',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.contentblocking_exceptions AS INT64))
      ),
      (
        'contentblocking_fastblock_enabled',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_fastblock_enabled = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_fastblock_enabled',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_fastblock_enabled = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_fingerprinting_blocking_enabled',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_fingerprinting_blocking_enabled = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_fingerprinting_blocking_enabled',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.contentblocking_fingerprinting_blocking_enabled = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'contentblocking_trackers_blocked_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.contentblocking_trackers_blocked_count AS INT64))
      ),
      (
        'contentblocking_trackers_blocked_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.contentblocking_trackers_blocked_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'contentblocking_trackers_blocked_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.contentblocking_trackers_blocked_count AS INT64))
      ),
      (
        'contentblocking_trackers_blocked_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.contentblocking_trackers_blocked_count AS INT64))
      ),
      (
        'contentblocking_trackers_blocked_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.contentblocking_trackers_blocked_count AS INT64))
      ),
      (
        'corroborate_omnijar_corrupted',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.corroborate_omnijar_corrupted = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'corroborate_omnijar_corrupted',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.corroborate_omnijar_corrupted = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'corroborate_omnijar_mismatch',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.corroborate_omnijar_mismatch = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'corroborate_omnijar_mismatch',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.corroborate_omnijar_mismatch = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'corroborate_system_addons_corrupted',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.corroborate_system_addons_corrupted = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'corroborate_system_addons_corrupted',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.corroborate_system_addons_corrupted = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'datasanitization_session_permission_exceptions',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.datasanitization_session_permission_exceptions AS INT64
          )
        )
      ),
      (
        'datasanitization_session_permission_exceptions',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.datasanitization_session_permission_exceptions
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'datasanitization_session_permission_exceptions',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.datasanitization_session_permission_exceptions AS INT64
          )
        )
      ),
      (
        'datasanitization_session_permission_exceptions',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.datasanitization_session_permission_exceptions AS INT64
          )
        )
      ),
      (
        'datasanitization_session_permission_exceptions',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.datasanitization_session_permission_exceptions AS INT64
          )
        )
      ),
      (
        'devtools_aboutdevtools_installed',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_installed AS INT64))
      ),
      (
        'devtools_aboutdevtools_installed',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_aboutdevtools_installed) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_aboutdevtools_installed',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_installed AS INT64))
      ),
      (
        'devtools_aboutdevtools_installed',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_installed AS INT64))
      ),
      (
        'devtools_aboutdevtools_installed',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_installed AS INT64))
      ),
      (
        'devtools_aboutdevtools_noinstall_exits',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_noinstall_exits AS INT64))
      ),
      (
        'devtools_aboutdevtools_noinstall_exits',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_aboutdevtools_noinstall_exits) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_aboutdevtools_noinstall_exits',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_noinstall_exits AS INT64))
      ),
      (
        'devtools_aboutdevtools_noinstall_exits',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_noinstall_exits AS INT64))
      ),
      (
        'devtools_aboutdevtools_noinstall_exits',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_noinstall_exits AS INT64))
      ),
      (
        'devtools_aboutdevtools_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_opened AS INT64))
      ),
      (
        'devtools_aboutdevtools_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_aboutdevtools_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_aboutdevtools_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_opened AS INT64))
      ),
      (
        'devtools_aboutdevtools_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_opened AS INT64))
      ),
      (
        'devtools_aboutdevtools_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_aboutdevtools_opened AS INT64))
      ),
      (
        'devtools_accessibility_accessible_context_menu_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_accessible_context_menu_opened AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_accessible_context_menu_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.devtools_accessibility_accessible_context_menu_opened
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_accessibility_accessible_context_menu_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_accessible_context_menu_opened AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_accessible_context_menu_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_accessible_context_menu_opened AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_accessible_context_menu_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_accessible_context_menu_opened AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_node_inspected_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_node_inspected_count AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_node_inspected_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_accessibility_node_inspected_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_accessibility_node_inspected_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_node_inspected_count AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_node_inspected_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_node_inspected_count AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_node_inspected_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_node_inspected_count AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_opened_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_accessibility_opened_count AS INT64))
      ),
      (
        'devtools_accessibility_opened_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_accessibility_opened_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_accessibility_opened_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_accessibility_opened_count AS INT64))
      ),
      (
        'devtools_accessibility_opened_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_accessibility_opened_count AS INT64))
      ),
      (
        'devtools_accessibility_opened_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_accessibility_opened_count AS INT64))
      ),
      (
        'devtools_accessibility_picker_used_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.devtools_accessibility_picker_used_count AS INT64)
        )
      ),
      (
        'devtools_accessibility_picker_used_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_accessibility_picker_used_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_accessibility_picker_used_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.devtools_accessibility_picker_used_count AS INT64)
        )
      ),
      (
        'devtools_accessibility_picker_used_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.devtools_accessibility_picker_used_count AS INT64)
        )
      ),
      (
        'devtools_accessibility_picker_used_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.devtools_accessibility_picker_used_count AS INT64)
        )
      ),
      (
        'devtools_accessibility_service_enabled_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_service_enabled_count AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_service_enabled_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.devtools_accessibility_service_enabled_count
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_accessibility_service_enabled_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_service_enabled_count AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_service_enabled_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_service_enabled_count AS INT64
          )
        )
      ),
      (
        'devtools_accessibility_service_enabled_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.devtools_accessibility_service_enabled_count AS INT64
          )
        )
      ),
      (
        'devtools_application_opened_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_application_opened_count AS INT64))
      ),
      (
        'devtools_application_opened_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_application_opened_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_application_opened_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_application_opened_count AS INT64))
      ),
      (
        'devtools_application_opened_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_application_opened_count AS INT64))
      ),
      (
        'devtools_application_opened_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_application_opened_count AS INT64))
      ),
      (
        'devtools_changesview_contextmenu',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu AS INT64))
      ),
      (
        'devtools_changesview_contextmenu',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_changesview_contextmenu) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_changesview_contextmenu',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu AS INT64))
      ),
      (
        'devtools_changesview_contextmenu',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu AS INT64))
      ),
      (
        'devtools_changesview_contextmenu',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu AS INT64))
      ),
      (
        'devtools_changesview_contextmenu_copy',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy AS INT64))
      ),
      (
        'devtools_changesview_contextmenu_copy',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_changesview_contextmenu_copy',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy AS INT64))
      ),
      (
        'devtools_changesview_contextmenu_copy',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy AS INT64))
      ),
      (
        'devtools_changesview_contextmenu_copy',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy AS INT64))
      ),
      (
        'devtools_changesview_contextmenu_copy_declaration',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_declaration AS INT64
          )
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_declaration',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_declaration
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_declaration',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_declaration AS INT64
          )
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_declaration',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_declaration AS INT64
          )
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_declaration',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_declaration AS INT64
          )
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_rule',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_rule AS INT64)
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_rule',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_rule) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_rule',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_rule AS INT64)
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_rule',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_rule AS INT64)
        )
      ),
      (
        'devtools_changesview_contextmenu_copy_rule',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.devtools_changesview_contextmenu_copy_rule AS INT64)
        )
      ),
      (
        'devtools_changesview_copy',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_changesview_copy AS INT64))
      ),
      (
        'devtools_changesview_copy',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.devtools_changesview_copy) IS NULL, NULL, COUNT(*))
      ),
      (
        'devtools_changesview_copy',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_changesview_copy AS INT64))
      ),
      (
        'devtools_changesview_copy',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_changesview_copy AS INT64))
      ),
      (
        'devtools_changesview_copy',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_changesview_copy AS INT64))
      ),
      (
        'devtools_changesview_copy_all_changes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_changesview_copy_all_changes AS INT64))
      ),
      (
        'devtools_changesview_copy_all_changes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_changesview_copy_all_changes) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_changesview_copy_all_changes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_changesview_copy_all_changes AS INT64))
      ),
      (
        'devtools_changesview_copy_all_changes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_changesview_copy_all_changes AS INT64))
      ),
      (
        'devtools_changesview_copy_all_changes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_changesview_copy_all_changes AS INT64))
      ),
      (
        'devtools_changesview_copy_rule',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_changesview_copy_rule AS INT64))
      ),
      (
        'devtools_changesview_copy_rule',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_changesview_copy_rule) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_changesview_copy_rule',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_changesview_copy_rule AS INT64))
      ),
      (
        'devtools_changesview_copy_rule',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_changesview_copy_rule AS INT64))
      ),
      (
        'devtools_changesview_copy_rule',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_changesview_copy_rule AS INT64))
      ),
      (
        'devtools_changesview_opened_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_changesview_opened_count AS INT64))
      ),
      (
        'devtools_changesview_opened_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_changesview_opened_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_changesview_opened_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_changesview_opened_count AS INT64))
      ),
      (
        'devtools_changesview_opened_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_changesview_opened_count AS INT64))
      ),
      (
        'devtools_changesview_opened_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_changesview_opened_count AS INT64))
      ),
      (
        'devtools_copy_full_css_selector_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_copy_full_css_selector_opened AS INT64))
      ),
      (
        'devtools_copy_full_css_selector_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_copy_full_css_selector_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_copy_full_css_selector_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_copy_full_css_selector_opened AS INT64))
      ),
      (
        'devtools_copy_full_css_selector_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_copy_full_css_selector_opened AS INT64))
      ),
      (
        'devtools_copy_full_css_selector_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_copy_full_css_selector_opened AS INT64))
      ),
      (
        'devtools_copy_unique_css_selector_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.devtools_copy_unique_css_selector_opened AS INT64)
        )
      ),
      (
        'devtools_copy_unique_css_selector_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_copy_unique_css_selector_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_copy_unique_css_selector_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.devtools_copy_unique_css_selector_opened AS INT64)
        )
      ),
      (
        'devtools_copy_unique_css_selector_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.devtools_copy_unique_css_selector_opened AS INT64)
        )
      ),
      (
        'devtools_copy_unique_css_selector_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.devtools_copy_unique_css_selector_opened AS INT64)
        )
      ),
      (
        'devtools_copy_xpath_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_copy_xpath_opened AS INT64))
      ),
      (
        'devtools_copy_xpath_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.devtools_copy_xpath_opened) IS NULL, NULL, COUNT(*))
      ),
      (
        'devtools_copy_xpath_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_copy_xpath_opened AS INT64))
      ),
      (
        'devtools_copy_xpath_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_copy_xpath_opened AS INT64))
      ),
      (
        'devtools_copy_xpath_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_copy_xpath_opened AS INT64))
      ),
      (
        'devtools_grid_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_grid_gridinspector_opened AS INT64))
      ),
      (
        'devtools_grid_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_grid_gridinspector_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_grid_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_grid_gridinspector_opened AS INT64))
      ),
      (
        'devtools_grid_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_grid_gridinspector_opened AS INT64))
      ),
      (
        'devtools_grid_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_grid_gridinspector_opened AS INT64))
      ),
      (
        'devtools_inspector_element_picker_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_inspector_element_picker_used AS INT64))
      ),
      (
        'devtools_inspector_element_picker_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_inspector_element_picker_used) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_inspector_element_picker_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_inspector_element_picker_used AS INT64))
      ),
      (
        'devtools_inspector_element_picker_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_inspector_element_picker_used AS INT64))
      ),
      (
        'devtools_inspector_element_picker_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_inspector_element_picker_used AS INT64))
      ),
      (
        'devtools_inspector_node_selection_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_inspector_node_selection_count AS INT64))
      ),
      (
        'devtools_inspector_node_selection_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_inspector_node_selection_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_inspector_node_selection_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_inspector_node_selection_count AS INT64))
      ),
      (
        'devtools_inspector_node_selection_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_inspector_node_selection_count AS INT64))
      ),
      (
        'devtools_inspector_node_selection_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_inspector_node_selection_count AS INT64))
      ),
      (
        'devtools_layout_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.devtools_layout_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_layout_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_layout_flexboxhighlighter_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_layout_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.devtools_layout_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_layout_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.devtools_layout_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_layout_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.devtools_layout_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_markup_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.devtools_markup_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_markup_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_markup_flexboxhighlighter_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_markup_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.devtools_markup_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_markup_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.devtools_markup_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_markup_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.devtools_markup_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_markup_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_markup_gridinspector_opened AS INT64))
      ),
      (
        'devtools_markup_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_markup_gridinspector_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_markup_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_markup_gridinspector_opened AS INT64))
      ),
      (
        'devtools_markup_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_markup_gridinspector_opened AS INT64))
      ),
      (
        'devtools_markup_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_markup_gridinspector_opened AS INT64))
      ),
      (
        'devtools_onboarding_is_devtools_user',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_onboarding_is_devtools_user = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_onboarding_is_devtools_user',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_onboarding_is_devtools_user = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_responsive_toolbox_opened_first',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.devtools_responsive_toolbox_opened_first AS INT64)
        )
      ),
      (
        'devtools_responsive_toolbox_opened_first',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_responsive_toolbox_opened_first) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_responsive_toolbox_opened_first',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.devtools_responsive_toolbox_opened_first AS INT64)
        )
      ),
      (
        'devtools_responsive_toolbox_opened_first',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.devtools_responsive_toolbox_opened_first AS INT64)
        )
      ),
      (
        'devtools_responsive_toolbox_opened_first',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.devtools_responsive_toolbox_opened_first AS INT64)
        )
      ),
      (
        'devtools_rules_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.devtools_rules_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_rules_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_rules_flexboxhighlighter_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_rules_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.devtools_rules_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_rules_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.devtools_rules_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_rules_flexboxhighlighter_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.devtools_rules_flexboxhighlighter_opened AS INT64)
        )
      ),
      (
        'devtools_rules_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_rules_gridinspector_opened AS INT64))
      ),
      (
        'devtools_rules_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_rules_gridinspector_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_rules_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_rules_gridinspector_opened AS INT64))
      ),
      (
        'devtools_rules_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_rules_gridinspector_opened AS INT64))
      ),
      (
        'devtools_rules_gridinspector_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_rules_gridinspector_opened AS INT64))
      ),
      (
        'devtools_shadowdom_reveal_link_clicked',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_shadowdom_reveal_link_clicked = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_shadowdom_reveal_link_clicked',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_shadowdom_reveal_link_clicked = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_shadowdom_shadow_root_displayed',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_shadowdom_shadow_root_displayed = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_shadowdom_shadow_root_displayed',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_shadowdom_shadow_root_displayed = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_shadowdom_shadow_root_expanded',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_shadowdom_shadow_root_expanded = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_shadowdom_shadow_root_expanded',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.devtools_shadowdom_shadow_root_expanded = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'devtools_toolbar_eyedropper_opened',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_toolbar_eyedropper_opened AS INT64))
      ),
      (
        'devtools_toolbar_eyedropper_opened',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_toolbar_eyedropper_opened) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_toolbar_eyedropper_opened',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_toolbar_eyedropper_opened AS INT64))
      ),
      (
        'devtools_toolbar_eyedropper_opened',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_toolbar_eyedropper_opened AS INT64))
      ),
      (
        'devtools_toolbar_eyedropper_opened',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_toolbar_eyedropper_opened AS INT64))
      ),
      (
        'devtools_webreplay_load_recording',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_webreplay_load_recording AS INT64))
      ),
      (
        'devtools_webreplay_load_recording',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_webreplay_load_recording) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_webreplay_load_recording',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_webreplay_load_recording AS INT64))
      ),
      (
        'devtools_webreplay_load_recording',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_webreplay_load_recording AS INT64))
      ),
      (
        'devtools_webreplay_load_recording',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_webreplay_load_recording AS INT64))
      ),
      (
        'devtools_webreplay_new_recording',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_webreplay_new_recording AS INT64))
      ),
      (
        'devtools_webreplay_new_recording',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_webreplay_new_recording) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_webreplay_new_recording',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_webreplay_new_recording AS INT64))
      ),
      (
        'devtools_webreplay_new_recording',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_webreplay_new_recording AS INT64))
      ),
      (
        'devtools_webreplay_new_recording',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_webreplay_new_recording AS INT64))
      ),
      (
        'devtools_webreplay_reload_recording',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_webreplay_reload_recording AS INT64))
      ),
      (
        'devtools_webreplay_reload_recording',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_webreplay_reload_recording) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_webreplay_reload_recording',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_webreplay_reload_recording AS INT64))
      ),
      (
        'devtools_webreplay_reload_recording',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_webreplay_reload_recording AS INT64))
      ),
      (
        'devtools_webreplay_reload_recording',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_webreplay_reload_recording AS INT64))
      ),
      (
        'devtools_webreplay_save_recording',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_webreplay_save_recording AS INT64))
      ),
      (
        'devtools_webreplay_save_recording',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_webreplay_save_recording) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_webreplay_save_recording',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_webreplay_save_recording AS INT64))
      ),
      (
        'devtools_webreplay_save_recording',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_webreplay_save_recording AS INT64))
      ),
      (
        'devtools_webreplay_save_recording',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_webreplay_save_recording AS INT64))
      ),
      (
        'devtools_webreplay_stop_recording',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.devtools_webreplay_stop_recording AS INT64))
      ),
      (
        'devtools_webreplay_stop_recording',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.devtools_webreplay_stop_recording) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'devtools_webreplay_stop_recording',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.devtools_webreplay_stop_recording AS INT64))
      ),
      (
        'devtools_webreplay_stop_recording',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.devtools_webreplay_stop_recording AS INT64))
      ),
      (
        'devtools_webreplay_stop_recording',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.devtools_webreplay_stop_recording AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_change_considered',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.dom_contentprocess_os_priority_change_considered AS INT64
          )
        )
      ),
      (
        'dom_contentprocess_os_priority_change_considered',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.dom_contentprocess_os_priority_change_considered
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'dom_contentprocess_os_priority_change_considered',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.dom_contentprocess_os_priority_change_considered AS INT64
          )
        )
      ),
      (
        'dom_contentprocess_os_priority_change_considered',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.dom_contentprocess_os_priority_change_considered AS INT64
          )
        )
      ),
      (
        'dom_contentprocess_os_priority_change_considered',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.dom_contentprocess_os_priority_change_considered AS INT64
          )
        )
      ),
      (
        'dom_contentprocess_os_priority_lowered',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_lowered AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_lowered',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.dom_contentprocess_os_priority_lowered) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'dom_contentprocess_os_priority_lowered',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_lowered AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_lowered',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_lowered AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_lowered',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_lowered AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_raised',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_raised AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_raised',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.dom_contentprocess_os_priority_raised) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'dom_contentprocess_os_priority_raised',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_raised AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_raised',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_raised AS INT64))
      ),
      (
        'dom_contentprocess_os_priority_raised',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.dom_contentprocess_os_priority_raised AS INT64))
      ),
      (
        'dom_contentprocess_troubled_due_to_memory',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.dom_contentprocess_troubled_due_to_memory AS INT64)
        )
      ),
      (
        'dom_contentprocess_troubled_due_to_memory',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.dom_contentprocess_troubled_due_to_memory) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'dom_contentprocess_troubled_due_to_memory',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.dom_contentprocess_troubled_due_to_memory AS INT64)
        )
      ),
      (
        'dom_contentprocess_troubled_due_to_memory',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.dom_contentprocess_troubled_due_to_memory AS INT64)
        )
      ),
      (
        'dom_contentprocess_troubled_due_to_memory',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.dom_contentprocess_troubled_due_to_memory AS INT64)
        )
      ),
      (
        'dom_parentprocess_private_window_used',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.dom_parentprocess_private_window_used = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'dom_parentprocess_private_window_used',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.dom_parentprocess_private_window_used = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'encoding_override_used',
        'boolean',
        '',
        'content',
        'false',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.encoding_override_used = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'encoding_override_used',
        'boolean',
        '',
        'content',
        'true',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.encoding_override_used = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'encoding_override_used',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.encoding_override_used = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'encoding_override_used',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.encoding_override_used = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill AS INT64)
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill AS INT64)
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill AS INT64)
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill AS INT64)
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill_update',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill_update AS INT64
          )
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill_update',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill_update
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill_update',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill_update AS INT64
          )
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill_update',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill_update AS INT64
          )
        )
      ),
      (
        'formautofill_addresses_fill_type_autofill_update',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.formautofill_addresses_fill_type_autofill_update AS INT64
          )
        )
      ),
      (
        'formautofill_addresses_fill_type_manual',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_manual AS INT64))
      ),
      (
        'formautofill_addresses_fill_type_manual',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.formautofill_addresses_fill_type_manual) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'formautofill_addresses_fill_type_manual',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_manual AS INT64))
      ),
      (
        'formautofill_addresses_fill_type_manual',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_manual AS INT64))
      ),
      (
        'formautofill_addresses_fill_type_manual',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.formautofill_addresses_fill_type_manual AS INT64))
      ),
      (
        'formautofill_availability',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.formautofill_availability = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'formautofill_availability',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.formautofill_availability = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'gfx_adapter_ram',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.gfx_adapter_ram AS INT64))
      ),
      (
        'gfx_adapter_ram',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.gfx_adapter_ram) IS NULL, NULL, COUNT(*))
      ),
      (
        'gfx_adapter_ram',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.gfx_adapter_ram AS INT64))
      ),
      (
        'gfx_adapter_ram',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.gfx_adapter_ram AS INT64))
      ),
      (
        'gfx_adapter_ram',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.gfx_adapter_ram AS INT64))
      ),
      (
        'gfx_display_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.gfx_display_count AS INT64))
      ),
      (
        'gfx_display_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.gfx_display_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'gfx_display_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.gfx_display_count AS INT64))
      ),
      (
        'gfx_display_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.gfx_display_count AS INT64))
      ),
      (
        'gfx_display_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.gfx_display_count AS INT64))
      ),
      (
        'gfx_display_primary_height',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.gfx_display_primary_height AS INT64))
      ),
      (
        'gfx_display_primary_height',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.gfx_display_primary_height) IS NULL, NULL, COUNT(*))
      ),
      (
        'gfx_display_primary_height',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.gfx_display_primary_height AS INT64))
      ),
      (
        'gfx_display_primary_height',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.gfx_display_primary_height AS INT64))
      ),
      (
        'gfx_display_primary_height',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.gfx_display_primary_height AS INT64))
      ),
      (
        'gfx_display_primary_width',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.gfx_display_primary_width AS INT64))
      ),
      (
        'gfx_display_primary_width',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.gfx_display_primary_width) IS NULL, NULL, COUNT(*))
      ),
      (
        'gfx_display_primary_width',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.gfx_display_primary_width AS INT64))
      ),
      (
        'gfx_display_primary_width',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.gfx_display_primary_width AS INT64))
      ),
      (
        'gfx_display_primary_width',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.gfx_display_primary_width AS INT64))
      ),
      (
        'gfx_hdr_windows_display_colorspace_bitfield',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.gfx_hdr_windows_display_colorspace_bitfield AS INT64
          )
        )
      ),
      (
        'gfx_hdr_windows_display_colorspace_bitfield',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.gfx_hdr_windows_display_colorspace_bitfield) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'gfx_hdr_windows_display_colorspace_bitfield',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.gfx_hdr_windows_display_colorspace_bitfield AS INT64
          )
        )
      ),
      (
        'gfx_hdr_windows_display_colorspace_bitfield',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.gfx_hdr_windows_display_colorspace_bitfield AS INT64
          )
        )
      ),
      (
        'gfx_hdr_windows_display_colorspace_bitfield',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.gfx_hdr_windows_display_colorspace_bitfield AS INT64
          )
        )
      ),
      (
        'gfx_headless',
        'boolean',
        '',
        'parent',
        'false',
        SUM(CASE WHEN payload.processes.parent.scalars.gfx_headless = FALSE THEN 1 ELSE 0 END)
      ),
      (
        'gfx_headless',
        'boolean',
        '',
        'parent',
        'true',
        SUM(CASE WHEN payload.processes.parent.scalars.gfx_headless = TRUE THEN 1 ELSE 0 END)
      ),
      (
        'gfx_omtp_paint_wait_ratio',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.gfx_omtp_paint_wait_ratio AS INT64))
      ),
      (
        'gfx_omtp_paint_wait_ratio',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.gfx_omtp_paint_wait_ratio) IS NULL, NULL, COUNT(*))
      ),
      (
        'gfx_omtp_paint_wait_ratio',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.gfx_omtp_paint_wait_ratio AS INT64))
      ),
      (
        'gfx_omtp_paint_wait_ratio',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.gfx_omtp_paint_wait_ratio AS INT64))
      ),
      (
        'gfx_omtp_paint_wait_ratio',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.gfx_omtp_paint_wait_ratio AS INT64))
      ),
      (
        'gfx_os_compositor',
        'boolean',
        '',
        'parent',
        'false',
        SUM(CASE WHEN payload.processes.parent.scalars.gfx_os_compositor = FALSE THEN 1 ELSE 0 END)
      ),
      (
        'gfx_os_compositor',
        'boolean',
        '',
        'parent',
        'true',
        SUM(CASE WHEN payload.processes.parent.scalars.gfx_os_compositor = TRUE THEN 1 ELSE 0 END)
      ),
      (
        'idb_failure_fileinfo_error',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.idb_failure_fileinfo_error AS INT64))
      ),
      (
        'idb_failure_fileinfo_error',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.idb_failure_fileinfo_error) IS NULL, NULL, COUNT(*))
      ),
      (
        'idb_failure_fileinfo_error',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.idb_failure_fileinfo_error AS INT64))
      ),
      (
        'idb_failure_fileinfo_error',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.idb_failure_fileinfo_error AS INT64))
      ),
      (
        'idb_failure_fileinfo_error',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.idb_failure_fileinfo_error AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.idb_type_persistent_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.idb_type_persistent_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_persistent_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.idb_type_persistent_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.idb_type_temporary_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.idb_type_temporary_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'idb_type_temporary_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.idb_type_temporary_count AS INT64))
      ),
      (
        'identity_fxaccounts_missed_commands_fetched',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.identity_fxaccounts_missed_commands_fetched AS INT64
          )
        )
      ),
      (
        'identity_fxaccounts_missed_commands_fetched',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.identity_fxaccounts_missed_commands_fetched) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'identity_fxaccounts_missed_commands_fetched',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.identity_fxaccounts_missed_commands_fetched AS INT64
          )
        )
      ),
      (
        'identity_fxaccounts_missed_commands_fetched',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.identity_fxaccounts_missed_commands_fetched AS INT64
          )
        )
      ),
      (
        'identity_fxaccounts_missed_commands_fetched',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.identity_fxaccounts_missed_commands_fetched AS INT64
          )
        )
      ),
      (
        'images_webp_content_observed',
        'boolean',
        '',
        'content',
        'false',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.images_webp_content_observed = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'images_webp_content_observed',
        'boolean',
        '',
        'content',
        'true',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.images_webp_content_observed = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'images_webp_content_observed',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.images_webp_content_observed = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'images_webp_content_observed',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.images_webp_content_observed = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'images_webp_probe_observed',
        'boolean',
        '',
        'content',
        'false',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.images_webp_probe_observed = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'images_webp_probe_observed',
        'boolean',
        '',
        'content',
        'true',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.images_webp_probe_observed = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'images_webp_probe_observed',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.images_webp_probe_observed = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'images_webp_probe_observed',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.images_webp_probe_observed = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'mathml_doc_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.mathml_doc_count AS INT64))
      ),
      (
        'mathml_doc_count',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.mathml_doc_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'mathml_doc_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.mathml_doc_count AS INT64))
      ),
      (
        'mathml_doc_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.mathml_doc_count AS INT64))
      ),
      (
        'mathml_doc_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.mathml_doc_count AS INT64))
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.media_allowed_autoplay_no_audio_track_count
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.media_allowed_autoplay_no_audio_track_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_allowed_autoplay_no_audio_track_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.media_allowed_autoplay_no_audio_track_count AS INT64
          )
        )
      ),
      (
        'media_autoplay_default_blocked',
        'boolean',
        '',
        'content',
        'false',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.media_autoplay_default_blocked = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'media_autoplay_default_blocked',
        'boolean',
        '',
        'content',
        'true',
        SUM(
          CASE
            WHEN payload.processes.content.scalars.media_autoplay_default_blocked = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'media_autoplay_default_blocked',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.media_autoplay_default_blocked = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'media_autoplay_default_blocked',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.media_autoplay_default_blocked = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.media_autoplay_would_be_allowed_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.media_autoplay_would_be_allowed_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_be_allowed_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.media_autoplay_would_be_allowed_count AS INT64))
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(payload.processes.content.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.media_autoplay_would_not_be_allowed_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(payload.processes.content.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(payload.processes.content.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(payload.processes.content.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.media_autoplay_would_not_be_allowed_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_autoplay_would_not_be_allowed_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.media_autoplay_would_not_be_allowed_count AS INT64)
        )
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.media_blocked_no_metadata) IS NULL, NULL, COUNT(*))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.media_blocked_no_metadata) IS NULL, NULL, COUNT(*))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.media_blocked_no_metadata AS INT64))
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.media_blocked_no_metadata_endup_no_audio_track
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.media_blocked_no_metadata_endup_no_audio_track
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_blocked_no_metadata_endup_no_audio_track',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.media_blocked_no_metadata_endup_no_audio_track AS INT64
          )
        )
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.media_page_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.media_page_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.media_page_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.media_page_had_media_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.media_page_had_media_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_media_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.media_page_had_media_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.media_page_had_play_revoked_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.media_page_had_play_revoked_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'media_page_had_play_revoked_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.media_page_had_play_revoked_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.mediarecorder_recording_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.mediarecorder_recording_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'mediarecorder_recording_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.mediarecorder_recording_count AS INT64))
      ),
      (
        'memoryreporter_max_ghost_windows',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.memoryreporter_max_ghost_windows AS INT64))
      ),
      (
        'memoryreporter_max_ghost_windows',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.memoryreporter_max_ghost_windows) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'memoryreporter_max_ghost_windows',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.memoryreporter_max_ghost_windows AS INT64))
      ),
      (
        'memoryreporter_max_ghost_windows',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.memoryreporter_max_ghost_windows AS INT64))
      ),
      (
        'memoryreporter_max_ghost_windows',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.memoryreporter_max_ghost_windows AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.navigator_storage_estimate_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.navigator_storage_estimate_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_estimate_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.navigator_storage_estimate_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.navigator_storage_persist_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.navigator_storage_persist_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'navigator_storage_persist_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.navigator_storage_persist_count AS INT64))
      ),
      (
        'network_tcp_overlapped_io_canceled_before_finished',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.network_tcp_overlapped_io_canceled_before_finished AS INT64
          )
        )
      ),
      (
        'network_tcp_overlapped_io_canceled_before_finished',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.network_tcp_overlapped_io_canceled_before_finished
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'network_tcp_overlapped_io_canceled_before_finished',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.network_tcp_overlapped_io_canceled_before_finished AS INT64
          )
        )
      ),
      (
        'network_tcp_overlapped_io_canceled_before_finished',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.network_tcp_overlapped_io_canceled_before_finished AS INT64
          )
        )
      ),
      (
        'network_tcp_overlapped_io_canceled_before_finished',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.network_tcp_overlapped_io_canceled_before_finished AS INT64
          )
        )
      ),
      (
        'network_tcp_overlapped_result_delayed',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.network_tcp_overlapped_result_delayed AS INT64))
      ),
      (
        'network_tcp_overlapped_result_delayed',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.network_tcp_overlapped_result_delayed) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'network_tcp_overlapped_result_delayed',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.network_tcp_overlapped_result_delayed AS INT64))
      ),
      (
        'network_tcp_overlapped_result_delayed',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.network_tcp_overlapped_result_delayed AS INT64))
      ),
      (
        'network_tcp_overlapped_result_delayed',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.network_tcp_overlapped_result_delayed AS INT64))
      ),
      (
        'networking_data_transferred_captive_portal',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.networking_data_transferred_captive_portal AS INT64)
        )
      ),
      (
        'networking_data_transferred_captive_portal',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.networking_data_transferred_captive_portal) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'networking_data_transferred_captive_portal',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.networking_data_transferred_captive_portal AS INT64)
        )
      ),
      (
        'networking_data_transferred_captive_portal',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.networking_data_transferred_captive_portal AS INT64)
        )
      ),
      (
        'networking_data_transferred_captive_portal',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.networking_data_transferred_captive_portal AS INT64)
        )
      ),
      (
        'networking_ftp_opened_channels_files',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_files AS INT64))
      ),
      (
        'networking_ftp_opened_channels_files',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.networking_ftp_opened_channels_files) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'networking_ftp_opened_channels_files',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_files AS INT64))
      ),
      (
        'networking_ftp_opened_channels_files',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_files AS INT64))
      ),
      (
        'networking_ftp_opened_channels_files',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_files AS INT64))
      ),
      (
        'networking_ftp_opened_channels_listings',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_listings AS INT64))
      ),
      (
        'networking_ftp_opened_channels_listings',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.networking_ftp_opened_channels_listings) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'networking_ftp_opened_channels_listings',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_listings AS INT64))
      ),
      (
        'networking_ftp_opened_channels_listings',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_listings AS INT64))
      ),
      (
        'networking_ftp_opened_channels_listings',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.networking_ftp_opened_channels_listings AS INT64))
      ),
      (
        'networking_http_connections_captive_portal',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.networking_http_connections_captive_portal AS INT64)
        )
      ),
      (
        'networking_http_connections_captive_portal',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.networking_http_connections_captive_portal) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'networking_http_connections_captive_portal',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.networking_http_connections_captive_portal AS INT64)
        )
      ),
      (
        'networking_http_connections_captive_portal',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.networking_http_connections_captive_portal AS INT64)
        )
      ),
      (
        'networking_http_connections_captive_portal',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.networking_http_connections_captive_portal AS INT64)
        )
      ),
      (
        'networking_http_transactions_captive_portal',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.networking_http_transactions_captive_portal AS INT64
          )
        )
      ),
      (
        'networking_http_transactions_captive_portal',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.networking_http_transactions_captive_portal) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'networking_http_transactions_captive_portal',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.networking_http_transactions_captive_portal AS INT64
          )
        )
      ),
      (
        'networking_http_transactions_captive_portal',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.networking_http_transactions_captive_portal AS INT64
          )
        )
      ),
      (
        'networking_http_transactions_captive_portal',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.networking_http_transactions_captive_portal AS INT64
          )
        )
      ),
      (
        'os_environment_is_admin_without_uac',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.os_environment_is_admin_without_uac = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'os_environment_is_admin_without_uac',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.os_environment_is_admin_without_uac = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.pdf_viewer_fallback_shown) IS NULL, NULL, COUNT(*))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.pdf_viewer_fallback_shown) IS NULL, NULL, COUNT(*))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_fallback_shown',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.pdf_viewer_fallback_shown AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.pdf_viewer_print) IS NULL, NULL, COUNT(*))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.pdf_viewer_print) IS NULL, NULL, COUNT(*))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_print',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.pdf_viewer_print AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.pdf_viewer_used) IS NULL, NULL, COUNT(*))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.pdf_viewer_used) IS NULL, NULL, COUNT(*))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'pdf_viewer_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.pdf_viewer_used AS INT64))
      ),
      (
        'policies_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.policies_count AS INT64))
      ),
      (
        'policies_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.policies_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'policies_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.policies_count AS INT64))
      ),
      (
        'policies_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.policies_count AS INT64))
      ),
      (
        'policies_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.policies_count AS INT64))
      ),
      (
        'preferences_created_new_user_prefs_file',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_created_new_user_prefs_file = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'preferences_created_new_user_prefs_file',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_created_new_user_prefs_file = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'preferences_prefs_file_was_invalid',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_prefs_file_was_invalid = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'preferences_prefs_file_was_invalid',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_prefs_file_was_invalid = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'preferences_prevent_accessibility_services',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_prevent_accessibility_services = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'preferences_prevent_accessibility_services',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_prevent_accessibility_services = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'preferences_read_user_js',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_read_user_js = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'preferences_read_user_js',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.preferences_read_user_js = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'pwmgr_potentially_breached_passwords',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.pwmgr_potentially_breached_passwords AS INT64))
      ),
      (
        'pwmgr_potentially_breached_passwords',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.pwmgr_potentially_breached_passwords) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'pwmgr_potentially_breached_passwords',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.pwmgr_potentially_breached_passwords AS INT64))
      ),
      (
        'pwmgr_potentially_breached_passwords',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.pwmgr_potentially_breached_passwords AS INT64))
      ),
      (
        'pwmgr_potentially_breached_passwords',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.pwmgr_potentially_breached_passwords AS INT64))
      ),
      (
        'qm_repositories_initialization_time',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.qm_repositories_initialization_time AS INT64))
      ),
      (
        'qm_repositories_initialization_time',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.qm_repositories_initialization_time) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'qm_repositories_initialization_time',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.qm_repositories_initialization_time AS INT64))
      ),
      (
        'qm_repositories_initialization_time',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.qm_repositories_initialization_time AS INT64))
      ),
      (
        'qm_repositories_initialization_time',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.qm_repositories_initialization_time AS INT64))
      ),
      (
        'screenshots_copy',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.screenshots_copy AS INT64))
      ),
      (
        'screenshots_copy',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.screenshots_copy) IS NULL, NULL, COUNT(*))
      ),
      (
        'screenshots_copy',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.screenshots_copy AS INT64))
      ),
      (
        'screenshots_copy',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.screenshots_copy AS INT64))
      ),
      (
        'screenshots_copy',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.screenshots_copy AS INT64))
      ),
      (
        'screenshots_download',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.screenshots_download AS INT64))
      ),
      (
        'screenshots_download',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.screenshots_download) IS NULL, NULL, COUNT(*))
      ),
      (
        'screenshots_download',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.screenshots_download AS INT64))
      ),
      (
        'screenshots_download',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.screenshots_download AS INT64))
      ),
      (
        'screenshots_download',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.screenshots_download AS INT64))
      ),
      (
        'screenshots_upload',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.screenshots_upload AS INT64))
      ),
      (
        'screenshots_upload',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.screenshots_upload) IS NULL, NULL, COUNT(*))
      ),
      (
        'screenshots_upload',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.screenshots_upload AS INT64))
      ),
      (
        'screenshots_upload',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.screenshots_upload AS INT64))
      ),
      (
        'screenshots_upload',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.screenshots_upload AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.script_preloader_mainthread_recompile) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.script_preloader_mainthread_recompile) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'script_preloader_mainthread_recompile',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.script_preloader_mainthread_recompile AS INT64))
      ),
      (
        'security_intermediate_preloading_num_pending',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_pending AS INT64
          )
        )
      ),
      (
        'security_intermediate_preloading_num_pending',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.security_intermediate_preloading_num_pending
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'security_intermediate_preloading_num_pending',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_pending AS INT64
          )
        )
      ),
      (
        'security_intermediate_preloading_num_pending',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_pending AS INT64
          )
        )
      ),
      (
        'security_intermediate_preloading_num_pending',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_pending AS INT64
          )
        )
      ),
      (
        'security_intermediate_preloading_num_preloaded',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_preloaded AS INT64
          )
        )
      ),
      (
        'security_intermediate_preloading_num_preloaded',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.security_intermediate_preloading_num_preloaded
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'security_intermediate_preloading_num_preloaded',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_preloaded AS INT64
          )
        )
      ),
      (
        'security_intermediate_preloading_num_preloaded',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_preloaded AS INT64
          )
        )
      ),
      (
        'security_intermediate_preloading_num_preloaded',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.security_intermediate_preloading_num_preloaded AS INT64
          )
        )
      ),
      (
        'security_tls_delegated_credentials_txn',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.security_tls_delegated_credentials_txn AS INT64))
      ),
      (
        'security_tls_delegated_credentials_txn',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.security_tls_delegated_credentials_txn) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'security_tls_delegated_credentials_txn',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.security_tls_delegated_credentials_txn AS INT64))
      ),
      (
        'security_tls_delegated_credentials_txn',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.security_tls_delegated_credentials_txn AS INT64))
      ),
      (
        'security_tls_delegated_credentials_txn',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.security_tls_delegated_credentials_txn AS INT64))
      ),
      (
        'startup_is_cold',
        'boolean',
        '',
        'parent',
        'false',
        SUM(CASE WHEN payload.processes.parent.scalars.startup_is_cold = FALSE THEN 1 ELSE 0 END)
      ),
      (
        'startup_is_cold',
        'boolean',
        '',
        'parent',
        'true',
        SUM(CASE WHEN payload.processes.parent.scalars.startup_is_cold = TRUE THEN 1 ELSE 0 END)
      ),
      (
        'storage_sync_api_usage_extensions_using',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.storage_sync_api_usage_extensions_using AS INT64))
      ),
      (
        'storage_sync_api_usage_extensions_using',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.storage_sync_api_usage_extensions_using) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'storage_sync_api_usage_extensions_using',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.storage_sync_api_usage_extensions_using AS INT64))
      ),
      (
        'storage_sync_api_usage_extensions_using',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.storage_sync_api_usage_extensions_using AS INT64))
      ),
      (
        'storage_sync_api_usage_extensions_using',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.storage_sync_api_usage_extensions_using AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.sw_alternative_body_used_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.sw_alternative_body_used_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_alternative_body_used_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.sw_alternative_body_used_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.sw_cors_res_for_so_req_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.sw_cors_res_for_so_req_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_cors_res_for_so_req_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.sw_cors_res_for_so_req_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.sw_synthesized_res_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.sw_synthesized_res_count) IS NULL, NULL, COUNT(*))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'sw_synthesized_res_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.sw_synthesized_res_count AS INT64))
      ),
      (
        'telemetry_about_telemetry_pageload',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.telemetry_about_telemetry_pageload AS INT64))
      ),
      (
        'telemetry_about_telemetry_pageload',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.telemetry_about_telemetry_pageload) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_about_telemetry_pageload',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.telemetry_about_telemetry_pageload AS INT64))
      ),
      (
        'telemetry_about_telemetry_pageload',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.telemetry_about_telemetry_pageload AS INT64))
      ),
      (
        'telemetry_about_telemetry_pageload',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.telemetry_about_telemetry_pageload AS INT64))
      ),
      (
        'telemetry_data_upload_optin',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.telemetry_data_upload_optin = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'telemetry_data_upload_optin',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.telemetry_data_upload_optin = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.telemetry_discarded_accumulations) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'gpu',
        'avg',
        AVG(CAST(payload.processes.gpu.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'gpu',
        'count',
        IF(
          MIN(payload.processes.gpu.scalars.telemetry_discarded_accumulations) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'gpu',
        'max',
        MAX(CAST(payload.processes.gpu.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'gpu',
        'min',
        MIN(CAST(payload.processes.gpu.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_accumulations',
        'scalar',
        '',
        'gpu',
        'sum',
        SUM(CAST(payload.processes.gpu.scalars.telemetry_discarded_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.telemetry_discarded_child_events) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'gpu',
        'avg',
        AVG(CAST(payload.processes.gpu.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'gpu',
        'count',
        IF(
          MIN(payload.processes.gpu.scalars.telemetry_discarded_child_events) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'gpu',
        'max',
        MAX(CAST(payload.processes.gpu.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'gpu',
        'min',
        MIN(CAST(payload.processes.gpu.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_child_events',
        'scalar',
        '',
        'gpu',
        'sum',
        SUM(CAST(payload.processes.gpu.scalars.telemetry_discarded_child_events AS INT64))
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_accumulations AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.telemetry_discarded_keyed_accumulations) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_accumulations AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_accumulations AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_accumulations AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'gpu',
        'avg',
        AVG(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'gpu',
        'count',
        IF(
          MIN(payload.processes.gpu.scalars.telemetry_discarded_keyed_accumulations) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'gpu',
        'max',
        MAX(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'gpu',
        'min',
        MIN(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_keyed_accumulations',
        'scalar',
        '',
        'gpu',
        'sum',
        SUM(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_accumulations AS INT64))
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_scalar_actions AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.telemetry_discarded_keyed_scalar_actions) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_scalar_actions AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_scalar_actions AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(payload.processes.content.scalars.telemetry_discarded_keyed_scalar_actions AS INT64)
        )
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'gpu',
        'avg',
        AVG(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'gpu',
        'count',
        IF(
          MIN(payload.processes.gpu.scalars.telemetry_discarded_keyed_scalar_actions) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'gpu',
        'max',
        MAX(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'gpu',
        'min',
        MIN(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_keyed_scalar_actions',
        'scalar',
        '',
        'gpu',
        'sum',
        SUM(CAST(payload.processes.gpu.scalars.telemetry_discarded_keyed_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.telemetry_discarded_scalar_actions) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'gpu',
        'avg',
        AVG(CAST(payload.processes.gpu.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'gpu',
        'count',
        IF(
          MIN(payload.processes.gpu.scalars.telemetry_discarded_scalar_actions) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'gpu',
        'max',
        MAX(CAST(payload.processes.gpu.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'gpu',
        'min',
        MIN(CAST(payload.processes.gpu.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_discarded_scalar_actions',
        'scalar',
        '',
        'gpu',
        'sum',
        SUM(CAST(payload.processes.gpu.scalars.telemetry_discarded_scalar_actions AS INT64))
      ),
      (
        'telemetry_os_shutting_down',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.telemetry_os_shutting_down = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'telemetry_os_shutting_down',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.telemetry_os_shutting_down = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'telemetry_pending_operations_highwatermark_reached',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.telemetry_pending_operations_highwatermark_reached AS INT64
          )
        )
      ),
      (
        'telemetry_pending_operations_highwatermark_reached',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.telemetry_pending_operations_highwatermark_reached
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_pending_operations_highwatermark_reached',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.telemetry_pending_operations_highwatermark_reached AS INT64
          )
        )
      ),
      (
        'telemetry_pending_operations_highwatermark_reached',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.telemetry_pending_operations_highwatermark_reached AS INT64
          )
        )
      ),
      (
        'telemetry_pending_operations_highwatermark_reached',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.telemetry_pending_operations_highwatermark_reached AS INT64
          )
        )
      ),
      (
        'telemetry_persistence_timer_hit_count',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.telemetry_persistence_timer_hit_count AS INT64))
      ),
      (
        'telemetry_persistence_timer_hit_count',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.telemetry_persistence_timer_hit_count) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_persistence_timer_hit_count',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.telemetry_persistence_timer_hit_count AS INT64))
      ),
      (
        'telemetry_persistence_timer_hit_count',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.telemetry_persistence_timer_hit_count AS INT64))
      ),
      (
        'telemetry_persistence_timer_hit_count',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.telemetry_persistence_timer_hit_count AS INT64))
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.telemetry_process_creation_timestamp_inconsistent
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.telemetry_process_creation_timestamp_inconsistent
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_process_creation_timestamp_inconsistent',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.telemetry_process_creation_timestamp_inconsistent AS INT64
          )
        )
      ),
      (
        'telemetry_profile_directory_scan_date',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scan_date AS INT64))
      ),
      (
        'telemetry_profile_directory_scan_date',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.telemetry_profile_directory_scan_date) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_profile_directory_scan_date',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scan_date AS INT64))
      ),
      (
        'telemetry_profile_directory_scan_date',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scan_date AS INT64))
      ),
      (
        'telemetry_profile_directory_scan_date',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scan_date AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.telemetry_profile_directory_scans) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'gpu',
        'avg',
        AVG(CAST(payload.processes.gpu.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'gpu',
        'count',
        IF(
          MIN(payload.processes.gpu.scalars.telemetry_profile_directory_scans) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'gpu',
        'max',
        MAX(CAST(payload.processes.gpu.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'gpu',
        'min',
        MIN(CAST(payload.processes.gpu.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'gpu',
        'sum',
        SUM(CAST(payload.processes.gpu.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.telemetry_profile_directory_scans) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'telemetry_profile_directory_scans',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.telemetry_profile_directory_scans AS INT64))
      ),
      (
        'timestamps_about_home_topsites_first_paint',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.timestamps_about_home_topsites_first_paint AS INT64)
        )
      ),
      (
        'timestamps_about_home_topsites_first_paint',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.timestamps_about_home_topsites_first_paint) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'timestamps_about_home_topsites_first_paint',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.timestamps_about_home_topsites_first_paint AS INT64)
        )
      ),
      (
        'timestamps_about_home_topsites_first_paint',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.timestamps_about_home_topsites_first_paint AS INT64)
        )
      ),
      (
        'timestamps_about_home_topsites_first_paint',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.timestamps_about_home_topsites_first_paint AS INT64)
        )
      ),
      (
        'timestamps_first_paint',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.timestamps_first_paint AS INT64))
      ),
      (
        'timestamps_first_paint',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.timestamps_first_paint) IS NULL, NULL, COUNT(*))
      ),
      (
        'timestamps_first_paint',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.timestamps_first_paint AS INT64))
      ),
      (
        'timestamps_first_paint',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.timestamps_first_paint AS INT64))
      ),
      (
        'timestamps_first_paint',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.timestamps_first_paint AS INT64))
      ),
      (
        'timestamps_first_paint_two',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.timestamps_first_paint_two AS INT64))
      ),
      (
        'timestamps_first_paint_two',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.timestamps_first_paint_two) IS NULL, NULL, COUNT(*))
      ),
      (
        'timestamps_first_paint_two',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.timestamps_first_paint_two AS INT64))
      ),
      (
        'timestamps_first_paint_two',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.timestamps_first_paint_two AS INT64))
      ),
      (
        'timestamps_first_paint_two',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.timestamps_first_paint_two AS INT64))
      ),
      (
        'update_fix_permissions_attempted',
        'boolean',
        '',
        'parent',
        'false',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.update_fix_permissions_attempted = FALSE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'update_fix_permissions_attempted',
        'boolean',
        '',
        'parent',
        'true',
        SUM(
          CASE
            WHEN payload.processes.parent.scalars.update_fix_permissions_attempted = TRUE
              THEN 1
            ELSE 0
          END
        )
      ),
      (
        'update_session_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_bytes
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_downloads_bits_partial_bytes) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_bytes
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_bytes
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_session_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_session_intervals_apply_complete AS INT64))
      ),
      (
        'update_session_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_intervals_apply_complete) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_session_intervals_apply_complete AS INT64))
      ),
      (
        'update_session_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_session_intervals_apply_complete AS INT64))
      ),
      (
        'update_session_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_session_intervals_apply_complete AS INT64))
      ),
      (
        'update_session_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_session_intervals_apply_partial AS INT64))
      ),
      (
        'update_session_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_intervals_apply_partial) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_session_intervals_apply_partial AS INT64))
      ),
      (
        'update_session_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_session_intervals_apply_partial AS INT64))
      ),
      (
        'update_session_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_session_intervals_apply_partial AS INT64))
      ),
      (
        'update_session_intervals_check',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_session_intervals_check AS INT64))
      ),
      (
        'update_session_intervals_check',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_intervals_check) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_check',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_session_intervals_check AS INT64))
      ),
      (
        'update_session_intervals_check',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_session_intervals_check AS INT64))
      ),
      (
        'update_session_intervals_check',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_session_intervals_check AS INT64))
      ),
      (
        'update_session_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_intervals_download_bits_complete
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_intervals_download_bits_partial
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_intervals_download_internal_complete
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_session_intervals_download_internal_partial
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_session_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_session_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_session_intervals_stage_complete AS INT64))
      ),
      (
        'update_session_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_intervals_stage_complete) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_session_intervals_stage_complete AS INT64))
      ),
      (
        'update_session_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_session_intervals_stage_complete AS INT64))
      ),
      (
        'update_session_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_session_intervals_stage_complete AS INT64))
      ),
      (
        'update_session_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_session_intervals_stage_partial AS INT64))
      ),
      (
        'update_session_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_intervals_stage_partial) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_session_intervals_stage_partial AS INT64))
      ),
      (
        'update_session_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_session_intervals_stage_partial AS INT64))
      ),
      (
        'update_session_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_session_intervals_stage_partial AS INT64))
      ),
      (
        'update_session_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_session_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_session_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_mar_complete_size_bytes) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_session_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_session_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_session_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_session_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_session_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_session_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_session_mar_partial_size_bytes AS INT64))
      ),
      (
        'update_session_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_session_mar_partial_size_bytes) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_session_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_session_mar_partial_size_bytes AS INT64))
      ),
      (
        'update_session_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_session_mar_partial_size_bytes AS INT64))
      ),
      (
        'update_session_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_session_mar_partial_size_bytes AS INT64))
      ),
      (
        'update_startup_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_bytes
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_complete_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_complete_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_downloads_bits_partial_bytes) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_bits_partial_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_bits_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_bytes
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_complete_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_complete_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_bytes
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_bytes AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_seconds
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_downloads_internal_partial_seconds',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_downloads_internal_partial_seconds AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_complete AS INT64))
      ),
      (
        'update_startup_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_intervals_apply_complete) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_complete AS INT64))
      ),
      (
        'update_startup_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_complete AS INT64))
      ),
      (
        'update_startup_intervals_apply_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_complete AS INT64))
      ),
      (
        'update_startup_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_partial AS INT64))
      ),
      (
        'update_startup_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_intervals_apply_partial) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_partial AS INT64))
      ),
      (
        'update_startup_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_partial AS INT64))
      ),
      (
        'update_startup_intervals_apply_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_startup_intervals_apply_partial AS INT64))
      ),
      (
        'update_startup_intervals_check',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_startup_intervals_check AS INT64))
      ),
      (
        'update_startup_intervals_check',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_intervals_check) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_check',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_startup_intervals_check AS INT64))
      ),
      (
        'update_startup_intervals_check',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_startup_intervals_check AS INT64))
      ),
      (
        'update_startup_intervals_check',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_startup_intervals_check AS INT64))
      ),
      (
        'update_startup_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_complete
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_bits_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_partial
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_bits_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_bits_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_complete
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_complete AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_partial
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_download_internal_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.update_startup_intervals_download_internal_partial AS INT64
          )
        )
      ),
      (
        'update_startup_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_complete AS INT64))
      ),
      (
        'update_startup_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_intervals_stage_complete) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_complete AS INT64))
      ),
      (
        'update_startup_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_complete AS INT64))
      ),
      (
        'update_startup_intervals_stage_complete',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_complete AS INT64))
      ),
      (
        'update_startup_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_partial AS INT64))
      ),
      (
        'update_startup_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_intervals_stage_partial) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_partial AS INT64))
      ),
      (
        'update_startup_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_partial AS INT64))
      ),
      (
        'update_startup_intervals_stage_partial',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_startup_intervals_stage_partial AS INT64))
      ),
      (
        'update_startup_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_startup_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_startup_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_mar_complete_size_bytes) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_startup_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_startup_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_startup_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_startup_mar_complete_size_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_startup_mar_complete_size_bytes AS INT64))
      ),
      (
        'update_startup_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.update_startup_mar_partial_size_bytes AS INT64))
      ),
      (
        'update_startup_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.update_startup_mar_partial_size_bytes) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'update_startup_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.update_startup_mar_partial_size_bytes AS INT64))
      ),
      (
        'update_startup_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.update_startup_mar_partial_size_bytes AS INT64))
      ),
      (
        'update_startup_mar_partial_size_bytes',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.update_startup_mar_partial_size_bytes AS INT64))
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_failed) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_failed) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_failed',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_succeeded
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_succeeded
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_disabled_succeeded',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_disabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_failed) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_failed) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_failed',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_failed AS INT64)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_succeeded
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_succeeded
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_hostnameobfuscation_enabled_succeeded',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.webrtc_hostnameobfuscation_enabled_succeeded AS INT64
          )
        )
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.webrtc_nicer_stun_retransmits) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.webrtc_nicer_stun_retransmits) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_stun_retransmits',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.webrtc_nicer_stun_retransmits AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.webrtc_nicer_turn_401s) IS NULL, NULL, COUNT(*))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.webrtc_nicer_turn_401s) IS NULL, NULL, COUNT(*))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_401s',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_401s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.webrtc_nicer_turn_403s) IS NULL, NULL, COUNT(*))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.webrtc_nicer_turn_403s) IS NULL, NULL, COUNT(*))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_403s',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_403s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'content',
        'count',
        IF(MIN(payload.processes.content.scalars.webrtc_nicer_turn_438s) IS NULL, NULL, COUNT(*))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'parent',
        'count',
        IF(MIN(payload.processes.parent.scalars.webrtc_nicer_turn_438s) IS NULL, NULL, COUNT(*))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_nicer_turn_438s',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.webrtc_nicer_turn_438s AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'content',
        'avg',
        AVG(CAST(payload.processes.content.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.webrtc_peerconnection_connected) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'content',
        'max',
        MAX(CAST(payload.processes.content.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'content',
        'min',
        MIN(CAST(payload.processes.content.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'content',
        'sum',
        SUM(CAST(payload.processes.content.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(CAST(payload.processes.parent.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.webrtc_peerconnection_connected) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'parent',
        'max',
        MAX(CAST(payload.processes.parent.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'parent',
        'min',
        MIN(CAST(payload.processes.parent.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_connected',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(CAST(payload.processes.parent.scalars.webrtc_peerconnection_connected AS INT64))
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.webrtc_peerconnection_datachannel_created) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.webrtc_peerconnection_datachannel_created) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_created',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_datachannel_created AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_life_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_life_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_life_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_and_life_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_and_life_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_datachannel_max_retx_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_datachannel_max_retx_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.webrtc_peerconnection_legacy_callback_stats_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.webrtc_peerconnection_legacy_callback_stats_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_legacy_callback_stats_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_legacy_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(
            payload.processes.content.scalars.webrtc_peerconnection_promise_and_callback_stats_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(
            payload.processes.content.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(
            payload.processes.parent.scalars.webrtc_peerconnection_promise_and_callback_stats_used
          ) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_and_callback_stats_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(
            payload.processes.parent.scalars.webrtc_peerconnection_promise_and_callback_stats_used AS INT64
          )
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'content',
        'avg',
        AVG(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'content',
        'count',
        IF(
          MIN(payload.processes.content.scalars.webrtc_peerconnection_promise_stats_used) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'content',
        'max',
        MAX(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'content',
        'min',
        MIN(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'content',
        'sum',
        SUM(
          CAST(payload.processes.content.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'parent',
        'avg',
        AVG(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'parent',
        'count',
        IF(
          MIN(payload.processes.parent.scalars.webrtc_peerconnection_promise_stats_used) IS NULL,
          NULL,
          COUNT(*)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'parent',
        'max',
        MAX(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'parent',
        'min',
        MIN(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'webrtc_peerconnection_promise_stats_used',
        'scalar',
        '',
        'parent',
        'sum',
        SUM(
          CAST(payload.processes.parent.scalars.webrtc_peerconnection_promise_stats_used AS INT64)
        )
      ),
      (
        'widget_dark_mode',
        'boolean',
        '',
        'parent',
        'false',
        SUM(CASE WHEN payload.processes.parent.scalars.widget_dark_mode = FALSE THEN 1 ELSE 0 END)
      ),
      (
        'widget_dark_mode',
        'boolean',
        '',
        'parent',
        'true',
        SUM(CASE WHEN payload.processes.parent.scalars.widget_dark_mode = TRUE THEN 1 ELSE 0 END)
      )
    ] AS scalar_aggregates
  FROM
    sampled_data
  GROUP BY
    submission_date,
    sample_id,
    client_id,
    os,
    app_version,
    app_build_id,
    channel
)
SELECT
  *
FROM
  aggregated
